# Copyright 2021 Le Filament (<http://www.le-filament.com>)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).

from odoo import api, fields, models


class AccCounter(models.Model):
    _name = "acc.counter"
    _description = "PRM"

    # ------------------------------------------------------
    # Fields declaration
    # ------------------------------------------------------
    # General Info
    name = fields.Char("ID PRM", required=True)
    acc_operation_id = fields.Many2one("acc.operation", string="Opération liée")
    date_start_contract = fields.Date("Date de début", default=fields.Datetime.now)
    date_end_contract = fields.Date("Date de fin", default=fields.Datetime.now)
    street = fields.Char("Rue")
    street2 = fields.Char("Complément de rue")
    zip = fields.Char("Code postal")
    city = fields.Char("Ville")
    partner_id = fields.Many2one(
        comodel_name="res.partner",
        string="Personne Physique",
        domain="['|', ('is_consumer', '=', True), ('is_producer', '=', True)]",
    )

    # Info Soutirage counter
    is_delivery = fields.Boolean("Est un point de soutirage")
    power_delivery = fields.Float("Puissance soutirage (en kW)")
    conso_annual = fields.Float("Estimation consomation annuelle (en kW)")

    # Info Injection counter
    is_injection = fields.Boolean("Est un point d'injection")
    prod_annual = fields.Float("Estimation production annuelle (en kWh)")
    # prod_annual = fields.Float(
    #     "Estimation production annuelle (en kWh)",
    #     compute='_compute_prod_annual')
    power_instal = fields.Float("Puissance de l'installation (en kW)")

    buyer_id = fields.Many2one(
        comodel_name="res.partner",
        string="Acheteur de surplus",
        domain="[('is_buyer_surplus', '=', True)]",
    )
    # ------------------------------------------------------
    # SQL Constraints
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Default methods
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Computed fields / Search Fields
    # ------------------------------------------------------
    # def _compute_prod_annual(self):
    #     for counter in self:
    #         if counter.power_instal:
    #             counter.prod_annual = 1250 * counter.power_instal
    # ------------------------------------------------------
    # Onchange / Constraints
    # ------------------------------------------------------
    @api.onchange("is_injection", "is_delivery")
    def _onchange_prm_type(self):
        domain = []
        if self.is_injection:
            domain = [("is_producer", "=", True)]
        if self.is_delivery:
            domain = [("is_consumer", "=", True)]
        if self.is_injection and self.is_delivery:
            domain = ["|", ("is_producer", "=", True), ("is_consumer", "=", True)]
        return {"domain": {"partner_id": domain}}

    @api.onchange("partner_id")
    def _onchange_partner_id(self):
        for counter in self:
            if counter.partner_id:
                counter.street = counter.partner_id.street
                counter.street2 = counter.partner_id.street2
                counter.zip = counter.partner_id.zip
                counter.city = counter.partner_id.city

    # ------------------------------------------------------
    # CRUD methods (ORM overrides)
    # ------------------------------------------------------
    def write(self, vals):
        for counter in self:
            if "partner_id" in vals:
                partner_id = self.env["res.partner"].browse(vals.get("partner_id"))
                counter.street = partner_id.street
                counter.street2 = partner_id.street2
                counter.zip = partner_id.zip
                counter.city = partner_id.city
        return super(AccCounter, self).write(vals)

    # ------------------------------------------------------
    # Actions
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Business methods
    # ------------------------------------------------------
